@@ -2,13 +2,12 @@
 Helpful DataFrame utilities
 """
 import pandas as pd
-
 from pandas.io.json import build_table_schema
 
 from .sql import cleanse_sql_name
 
 
-def build_schema(
+def build_dataframe_schema(
         df: pd.DataFrame,
         include_index=False
     ) -> dict:
@@ -28,10 +27,10 @@ def cleanse_sql_dataframe(
     """
     Renames all columns in a pandas dataframe to SQL compliant names in place
     """
-    df.rename(columns={r: cleanse_sql_name(r) for r in build_schema(df)},
+    df.rename(columns={r: cleanse_sql_name(r) for r in build_dataframe_schema(df)},
                 inplace=True)
 
-def generate_ddl(
+def generate_dataframe_ddl(
         df: pd.DataFrame,
         table_name: str
     ) -> str:
